@@ -211,14 +211,11 @@ sub new {
     my ($self, %options) = @_;
     $self = $self->SUPER::new(%options);
 
+    # Do not cache a Mail::SPF::MacroString instance with
+    # context provided, this causes a circular reference that leaks
+    # both objects.
     $self->{default_authority_explanation} = $self->default_default_authority_explanation
         if not defined($self->{default_authority_explanation});
-    $self->{default_authority_explanation} = Mail::SPF::MacroString->new(
-        text            => $self->{default_authority_explanation},
-        server          => $self,
-        is_explanation  => TRUE
-    )
-        if not UNIVERSAL::isa($self->{default_authority_explanation}, 'Mail::SPF::MacroString');
 
     $self->{hostname} ||= Mail::SPF::Util->hostname;
 
@@ -332,7 +329,11 @@ sub process {
         $result = $self->result_class('temperror')->new($self, $request, shift->text);
     }
     catch Mail::SPF::ENoAcceptableRecord with {
-        $result = $self->result_class('none'     )->new($self, $request, shift->text);
+	if((not defined $request->{record}->{terms}[0]->{domain_spec}->{text}) or ($request->{record}->{terms}[0]->{domain_spec}->{text} !~ /\.\./)) {
+          $result = $self->result_class('none'     )->new($self, $request, shift->text);
+        } else {
+          $result = $self->result_class('permerror')->new($self, $request, shift->text);
+        }
     }
     catch Mail::SPF::ERedundantAcceptableRecords with {
         $result = $self->result_class('permerror')->new($self, $request, shift->text);
@@ -559,6 +560,8 @@ error (other than RCODE 3 AKA C<NXDOMAIN>) occurred.
 sub dns_lookup {
     my ($self, $domain, $rr_type) = @_;
 
+    my $packet;
+
     if (UNIVERSAL::isa($domain, 'Mail::SPF::MacroString')) {
         $domain = $domain->expand;
         # Truncate overlong labels at 63 bytes (RFC 4408, 8.1/27):
@@ -570,11 +573,16 @@ sub dns_lookup {
 
     $domain =~ s/^(.*?)\.?$/\L$1/;  # Normalize domain.
 
-    my $packet = $self->dns_resolver->send($domain, $rr_type);
+    try {
+      $packet = $self->dns_resolver->send($domain, $rr_type);
+    }
+    otherwise {
+       throw Mail::SPF::ENoAcceptableRecord($self->dns_resolver->errorstring);
+    };
 
     # Throw DNS exception unless an answer packet with RCODE 0 or 3 (NXDOMAIN)
     # was received (thereby treating NXDOMAIN as an acceptable but empty answer packet):
-    $self->dns_resolver->errorstring !~ /^(timeout|query timed out)$/
+    defined $self->dns_resolver->errorstring and $self->dns_resolver->errorstring !~ /^(timeout|query timed out)$/
         or throw Mail::SPF::EDNSTimeout(
             "Time-out on DNS '$rr_type' lookup of '$domain'");
     defined($packet)
@@ -652,6 +660,18 @@ Returns the default authority explanation as a I<MacroString> object.  See the
 description of the L</new> constructor's C<default_authority_explanation>
 option.
 
+=cut
+
+sub default_authority_explanation {
+    my ($self) = @_;
+
+    return Mail::SPF::MacroString->new(
+        text            => $self->{default_authority_explanation},
+        server          => $self,
+        is_explanation  => TRUE
+    );
+}
+
 =item B<hostname>: returns I<string>
 
 Returns the local system's host name.  See the description of the L</new>
@@ -686,7 +706,6 @@ L</new> constructor's corresponding options.
 # Make read-only accessors:
 __PACKAGE__->make_accessor($_, TRUE)
     foreach qw(
-        default_authority_explanation
         hostname
 
         dns_resolver
